************************
fastapi_aad_auth
************************

.. image:: https://img.shields.io/github/license/djpugh/fastapi_aad_auth.svg
    :target: https://github.com/djpugh/fastapi_aad_auth/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/fastapi_aad_auth?style=flat-square
    :target: https://pypi.org/project/fastapi_aad_auth

.. image:: https://img.shields.io/pypi/implementation/fastapi_aad_auth?style=flat-square
    :target: https://pypi.org/project/fastapi_aad_auth

.. image:: https://img.shields.io/pypi/pyversions/fastapi_aad_auth?style=flat-square
    :target: https://pypi.org/project/fastapi_aad_auth

.. image:: https://img.shields.io/pypi/dm/fastapi_aad_auth?style=flat-square
    :target: https://pypistats.org/packages/fastapi_aad_auth

.. image:: https://img.shields.io/pypi/l/fastapi_aad_auth?style=flat-square
    :target: https://opensource.org/licenses/MIT

.. image:: https://github.com/djpugh/fastapi_aad_auth/workflows/Pipeline/badge.svg?branch=master&event=push
    :target: https://github.com/djpugh/fastapi_aad_auth/actions?query=workflow%3APipeline

.. image:: https://codecov.io/gh/djpugh/fastapi_aad_auth/branch/master/graph/badge.svg?token=APZ8YDJ0UD
    :target: https://codecov.io/gh/djpugh/fastapi_aad_auth

.. image:: https://app.fossa.com/api/projects/custom%2B20832%2Fgithub.com%2Fdjpugh%2Ffastapi_aad_auth.svg?type=shield
    :target: https://app.fossa.com/projects/custom%2B20832%2Fgithub.com%2Fdjpugh%2Ffastapi_aad_auth?ref=badge_shield

.. image:: https://sonarcloud.io/api/project_badges/measure?project=djpugh_fastapi_aad_auth&metric=alert_status
    :target: https://sonarcloud.io/dashboard?id=djpugh_fastapi_aad_auth

.. image:: https://img.shields.io/github/issues/djpugh/fastapi_aad_auth
    :target: https://github.com/djpugh/fastapi_aad_auth/issues

.. image:: https://img.shields.io/github/issues-pr-raw/djpugh/fastapi_aad_auth
    :target: https://github.com/djpugh/fastapi_aad_auth/pulls


Add Azure Active Directory Authentication for FastAPI, including for REST API Documentation


Links
-----

* `Full Documentation <https://djpugh.github.io/fastapi_aad_auth>`_
* `Installation <https://djpugh.github.io/fastapi_aad_auth/installation.html>`_
* `Configuring FastAPI to use AAD Auth <https://djpugh.github.io/fastapi_aad_auth/usage.html>`_
* `Changelog <https://djpugh.github.io/fastapi_aad_auth/changelog.html>`_
* `Contributing <https://djpugh.github.io/fastapi_aad_auth/development.html>`_
* `Issues <https://github.com/djpugh/fastapi_aad_auth/issues>`_
* `PyPI <https://pypi.org/project/fastapi_aad_auth>`_
* |github| `Github <https://github.com/djpugh/fastapi_aad_auth>`_

.. |github| image:: https://api.iconify.design/logos-github-icon.svg
    :target: https://github.com/djpugh/fastapi_aad_auth


Coverage
~~~~~~~~

.. image:: https://codecov.io/gh/djpugh/fastapi_aad_auth/branch/master/graphs/sunburst.svg?token=APZ8YDJ0UD
    :target: https://codecov.io/gh/djpugh/fastapi_aad_auth

License Analysis
~~~~~~~~~~~~~~~~

.. image:: https://app.fossa.com/api/projects/custom%2B20832%2Fgithub.com%2Fdjpugh%2Ffastapi_aad_auth.svg?type=large
    :target: https://app.fossa.com/projects/custom%2B20832%2Fgithub.com%2Fdjpugh%2Ffastapi_aad_auth?ref=badge_shield

---------------------------

(Built from `package-template <https://github.com/djpugh/package-template>`_ version 1.0.0)